<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Neeon_Core;

use NeeonTheme;
use NeeonTheme_Helper;
use \WP_Query;

$prefix      = NEEON_CORE_THEME_PREFIX;
$thumb_size  = 'neeon-size4';

if ( get_query_var('paged') ) {
	$paged = get_query_var('paged');
}
else if ( get_query_var('page') ) {
	$paged = get_query_var('page');
}
else {
	$paged = 1;
}

$args = array(
	'post_type'      => 'neeon_team',
	'posts_per_page' => $data['number'],
	'orderby'        => $data['orderby'],
	'paged' => $paged
);

if ( !empty( $data['cat'] ) ) {
	$args['tax_query'] = array(
		array(
			'taxonomy' => 'neeon_team_category',
			'field' => 'term_id',
			'terms' => $data['cat'],
		)
	);
}

switch ( $data['orderby'] ) {
	case 'title':
	case 'menu_order':
	$args['order'] = 'ASC';
	break;
}

$query = new WP_Query( $args );
$temp = NeeonTheme_Helper::wp_set_temp_query( $query );
$col_class = "col-lg-{$data['col_lg']} col-md-{$data['col_md']} col-sm-{$data['col_sm']} col-xs-{$data['col_xs']}";
?>
<div class="team-default team-multi-layout-2 team-grid-<?php echo esc_attr( $data['style'] );?>">
	<div class="row <?php echo esc_attr( $data['item_space'] );?>">
		<?php $i = $data['delay']; $j = $data['duration'];
			if ( $query->have_posts() ) {
			while ( $query->have_posts() ) {
				$query->the_post();
				$id            = get_the_id();
				$position   	= get_post_meta( $id, 'neeon_team_position', true );
				$socials       = get_post_meta( $id, 'neeon_team_socials', true );
				$social_fields = NeeonTheme_Helper::team_socials();
				if ( $data['contype'] == 'content' ) {
					$content = apply_filters( 'the_content', get_the_content() );
				}
				else {
					$content = apply_filters( 'the_excerpt', get_the_excerpt() );;
				}
				$content = wp_trim_words( $content, $data['count'], '' );
				$content = "$content";
				?>
				<div class="<?php echo esc_attr( $col_class );?>">
					<div class="team-item <?php echo esc_attr( $data['animation'] );?> <?php echo esc_attr( $data['animation_effect'] );?>" data-wow-delay="<?php echo esc_attr( $i );?>s" data-wow-duration="<?php echo esc_attr( $j );?>s">
						<div class="team-content-wrap">		
							<div class="team-thums">
								<a href="<?php the_permalink();?>">
									<?php
									if ( has_post_thumbnail() ){
										the_post_thumbnail( $thumb_size );
									}
									else {
										if ( !empty( NeeonTheme::$options['no_preview_image']['id'] ) ) {
											echo wp_get_attachment_image( NeeonTheme::$options['no_preview_image']['id'], $thumb_size );
										}
										else {
											echo '<img class="wp-post-image" src="' . NeeonTheme_Helper::get_img( 'noimage_480X504.jpg' ) . '" alt="'.get_the_title().'">';
										}
									}
									?>
								</a>
								<?php if ( !empty( $socials ) && $data['social_display']  == 'yes' ) { ?>
									<ul class="team-social">
										<?php foreach ( $socials as $key => $social ): ?>
											<?php if ( !empty( $social ) ): ?>
												<li><a target="_blank" href="<?php echo esc_url( $social );?>"><i class="fab <?php echo esc_attr( $social_fields[$key]['icon'] );?>" aria-hidden="true"></i></a></li>
											<?php endif; ?>
										<?php endforeach; ?>
									</ul>
								<?php } ?>
							</div>
							<div class="mask-wrap">
								<div class="team-content">
									<h3 class="team-title"><a href="<?php the_permalink();?>"><?php the_title();?></a><?php if ( $data['designation_display']  == 'yes' ) { ?><span> - <?php echo esc_html( $position );?></span><?php } ?></h3>
									<?php if ( $data['content_display']  == 'yes' ) { ?>
									<p><?php echo wp_kses( $content , 'alltext_allow' ); ?></p>
									<?php } ?>
								</div>
							</div>
						</div>
					</div>
				</div>
			<?php $i = $i + 0.2; $j = $j + 0.1; } ?>
		<?php } ?>
		<?php //wp_reset_postdata();?>
	</div>
	<?php if ( $data['more_button'] == 'show' ) { ?>
		<?php if ( !empty( $data['see_button_text'] ) ) { ?>
		<div class="team-button"><a class="button-style-2 btn-common rt-animation-out" href="<?php echo esc_url( $data['see_button_link'] );?>"><?php echo esc_html( $data['see_button_text'] );?><svg
                xmlns="http://www.w3.org/2000/svg"
                xmlns:xlink="http://www.w3.org/1999/xlink"
                width="34px"
                height="16px"
                viewBox="0 0 34.53 16"
                xml:space="preserve"
              >
                <rect
                  class="rt-button-line"
                  y="7.6"
                  width="34"
                  height=".4"
                ></rect>
                <g class="rt-button-cap-fake">
                  <path
                    class="rt-button-cap"
                    d="M25.83.7l.7-.7,8,8-.7.71Zm0,14.6,8-8,.71.71-8,8Z"
                  ></path>
                </g>
              </svg></a></div>
		<?php } ?>
	<?php } else { ?>
		<?php NeeonTheme_Helper::pagination(); ?>
	<?php } ?>
	<?php NeeonTheme_Helper::wp_reset_temp_query( $temp ); ?>
</div>