<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Neeon_Core;
use Elementor\Group_Control_Image_Size;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Css_Filter;


if ( ! defined( 'ABSPATH' ) ) exit;

class RT_Banner_Slider extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = esc_html__( 'RT Banner Slider', 'neeon-core' );
		$this->rt_base = 'rt-banner-slider';		
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'banner_image', [
                'type' => Controls_Manager::MEDIA,
                'label' =>   esc_html__('Image', 'neeon-core'),
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],                
            ]
        );
		$repeater->add_control(
            'slider_sub_title', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Sub title', 'neeon-core'),
                'label_block' => true, 
                'default' => esc_html__('BEST IT SOLUTION PROVIDER', 'neeon-core' ),
            ]
        );
		$repeater->add_control(
            'slider_title', [
                'type' => Controls_Manager::TEXT,
                'label' =>   esc_html__('Title', 'neeon-core'),
                'label_block' => true,
                'default' => esc_html__('Web Development & Custom Solutions', 'neeon-core' ),
            ]
        );
		$repeater->add_control(
            'slider_text', [
                'type' => Controls_Manager::TEXTAREA,
                'label' =>   esc_html__('Description', 'neeon-core'),
                'default' => esc_html__( 'Grursus suada faci Lorem ipsum dolarorit ametion consectetur elit. Vesti at bulum nec odio aea the dumm ipsumm and fadolorit to the consectetur dummy text elit.', 'neeon-core' ),
				'label_block' => true, 
            ]
        );
		$repeater->add_control(
            'button_text', [
                'type' => Controls_Manager::TEXT,
                'label'   => esc_html__( 'Button Text', 'neeon-core' ),
				'default' => esc_html__( 'Get Details', 'neeon-core' ),
                'label_block' => true,
            ]
        );
		$repeater->add_control(
            'button_url', [
                'type' => Controls_Manager::URL,
                'label'   => esc_html__( 'Button URL', 'neeon-core' ),
				'placeholder' => esc_url('https://your-link.com' ),
                'label_block' => true, 
            ]
        );
		
		$fields=array(
            array(
				'mode'    => 'section_start',
				'id'      => 'sec_general',
				'label'   => esc_html__( 'Banner Slider', 'neeon-core' ),
			),
            array(
				'type' => Controls_Manager::CHOOSE,
				'id'      => 'content_align',
				'mode'    => 'responsive',
				'label'   => esc_html__( 'Alignment', 'neeon-core' ),
				'options' => array(
					'left' => array(
						'title' => __( 'Left', 'elementor' ),
						'icon' => 'eicon-text-align-left',
					),
					'center' => array(
						'title' => __( 'Center', 'elementor' ),
						'icon' => 'eicon-text-align-center',
					),
					'right' => array(
						'title' => __( 'Right', 'elementor' ),
						'icon' => 'eicon-text-align-right',
					),
				),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .banner-slider .slider-content' => 'text-align: {{VALUE}}',
				),
			),
            array(
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'banner_lists',
				'label'   => esc_html__( 'Slider Items', 'neeon-core' ),
				'fields' => $repeater->get_controls(),
				'default' => array(
					['title' => 'Web Development & Custom Solutions', ],
					['title' => 'Web Development & Custom Solutions', ],
					['title' => 'Web Development & Custom Solutions', ],
				),
			),
            array(
				'type'    => Group_Control_Css_Filter::get_type(),
				'mode'    => 'group',				
				'label'   => esc_html__( 'Image Blend', 'neeon-core' ),	
				'name' => 'blend', 
				'selector' => '{{WRAPPER}} .banner-slider .swiper-slide:after',		
			),
			array(
				'type' 			=> Controls_Manager::SLIDER,
				'mode' 			=> 'responsive',
				'id'      		=> 'slide_height',
				'label'   		=> esc_html__( 'Slide Height', 'neeon-core' ),						
				'size_units' => array( 'px', '%' ),
				'default' => array(
					'unit' => 'px',
					'size' => '',
				),
				'range' => array(
	                'px' => array(
	                    'min' => 0,
	                    'max' => 1200,
	               	),
	               	'%' => array(
	                    'min' => 0,
	                    'max' => 100,
	               	),
		       	),
				'selectors' => array(
					'{{WRAPPER}} .banner-slider .single-slider' => 'min-height: {{SIZE}}{{UNIT}};',
				)
			),
            array(
				'mode' => 'section_end',
			),
            // Slider options
			array(
				'mode'        => 'section_start',
				'id'          => 'sec_slider',
				'label'       => esc_html__( 'Slider Options', 'neeon-core' ),
			),			
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'slider_autoplay',
				'label'       => esc_html__( 'Autoplay', 'neeon-core' ),
				'label_on'    => esc_html__( 'On', 'neeon-core' ),
				'label_off'   => esc_html__( 'Off', 'neeon-core' ),
				'default'     => 'yes',
				'description' => esc_html__( 'Enable or disable autoplay. Default: On', 'neeon-core' ),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'display_arrow',
				'label'       => esc_html__( 'Navigation Arrow', 'neeon-core' ),
				'label_on'    => esc_html__( 'On', 'neeon-core' ),
				'label_off'   => esc_html__( 'Off', 'neeon-core' ),
				'default'     => 'yes',
				'description' => esc_html__( 'Navigation Arrow. Default: On', 'neeon-core' ),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'display_buttet',
				'label'       => esc_html__( 'Pagination', 'neeon-core' ),
				'label_on'    => esc_html__( 'On', 'neeon-core' ),
				'label_off'   => esc_html__( 'Off', 'neeon-core' ),
				'default'     => 'yes',
				'description' => esc_html__( 'Navigation Arrow. Default: On', 'neeon-core' ),
			),
			array(
				'type'    => Controls_Manager::SLIDER,
				'mode' 			=> 'responsive',
				'id'      => 'slides_per_group',
				'label'   => esc_html__( 'slides Per Group', 'neeon-core' ),
				'default' => array(
					'size' => 1,
				),
				'description' => esc_html__( 'slides Per Group. Default: 1', 'neeon-core' ),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'centered_slides',
				'label'       => esc_html__( 'Centered Slides', 'consalty-core' ),
				'label_on'    => esc_html__( 'On', 'consalty-core' ),
				'label_off'   => esc_html__( 'Off', 'consalty-core' ),
				'default'     => 'yes',
				'description' => esc_html__( 'Centered Slides. Default: On', 'consalty-core' ),
				
			),
			array(
				'type'        => Controls_Manager::NUMBER,
				'id'          => 'slides_space',
				'label'       => esc_html__( 'Slides Space', 'consalty-core' ),
				'default'     => 10,
				'description' => esc_html__( 'Slides Space. Default: 10', 'consalty-core' ),
			),		
			array(
				'type'    => Controls_Manager::NUMBER,
				'id'      => 'slider_autoplay_delay',
				'label'   => esc_html__( 'Autoplay Slide Delay', 'neeon-core' ),
				'default' => 5000,
				'description' => esc_html__( 'Set any value for example 5 seconds to play it in every 5 seconds. Default: 5 Seconds', 'neeon-core' ),
				'condition'   => array( 'slider_autoplay' => 'yes' ),
			),
			array(
				'type'    => Controls_Manager::NUMBER,
				'id'      => 'slider_autoplay_speed',
				'label'   => esc_html__( 'Autoplay Slide Speed', 'neeon-core' ),
				'default' => 1000,
				'description' => esc_html__( 'Set any value for example .8 seconds to play it in every 2 seconds. Default: .8 Seconds', 'neeon-core' ),
				'condition'   => array( 'slider_autoplay' => 'yes' ),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'slider_loop',
				'label'       => esc_html__( 'Loop', 'neeon-core' ),
				'label_on'    => esc_html__( 'On', 'neeon-core' ),
				'label_off'   => esc_html__( 'Off', 'neeon-core' ),
				'default'     => 'yes',
				'description' => esc_html__( 'Loop to first item. Default: On', 'neeon-core' ),
			),
			array(
				'mode' => 'section_end',
			),

            // Title style
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_title_style',
				'label'   => esc_html__( 'Title Style', 'neeon-core' ),
				'tab'     => Controls_Manager::TAB_STYLE,
			),
			array (
				'mode'    => 'group',
				'type'    => Group_Control_Typography::get_type(),
				'name'    => 'title_typo',
				'label'   => esc_html__( 'Title Typo', 'neeon-core' ),
				'selector' => '{{WRAPPER}} .banner-slider .slider-content .slider-title',
			),
            array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'title_color',
				'label'   => esc_html__( 'Title Color', 'neeon-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .banner-slider .slider-content .slider-title' => 'color: {{VALUE}}',
				),
			),
            array(
				'type'    => Controls_Manager::DIMENSIONS,
				'id'      => 'title_margin',
				'mode'    => 'responsive',
				'label'   => esc_html__( 'Title Space', 'neeon-core' ),
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .banner-slider .slider-content .slider-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			),
			array(
				'type' => Controls_Manager::CHOOSE,
				'id'      => 'title_align',
				'label'   => esc_html__( 'Alignment', 'neeon-core' ),
				'options' => array(
					'left' => array(
						'title' => __( 'Left', 'elementor' ),
						'icon' => 'eicon-text-align-left',
					),
					'center' => array(
						'title' => __( 'Center', 'elementor' ),
						'icon' => 'eicon-text-align-center',
					),
					'right' => array(
						'title' => __( 'Right', 'elementor' ),
						'icon' => 'eicon-text-align-right',
					),
				),
				'default' => '',
			),
			array(
				'type' 			=> Controls_Manager::SLIDER,
				'mode' 			=> 'responsive',
				'id'      		=> 'title_width',
				'label'   		=> esc_html__( 'Title Width', 'neeon-core' ),						
				'size_units' => array( 'px', '%' ),
				'default' => array(
				'unit' => '%',
				'size' => '',
				),
				'range' => array(
	                'px' => array(
	                    'min' => 0,
	                    'max' => 1200,
	               	),
	               	'%' => array(
	                    'min' => 0,
	                    'max' => 100,
	               	),
		       	),
				'selectors' => array(
					'{{WRAPPER}} .banner-slider .slider-content .slider-title' => 'max-width: {{SIZE}}{{UNIT}};',
				)
			),
            array(
				'mode' => 'section_end',
			),
            // SubTitle style
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_subtitle_style',
				'label'   => esc_html__( 'Subtitle Style', 'neeon-core' ),
				'tab'     => Controls_Manager::TAB_STYLE,
			),
			array (
				'mode'    => 'group',
				'type'    => Group_Control_Typography::get_type(),
				'name'    => 'subtitle_typo',
				'label'   => esc_html__( 'Subtitle Typo', 'neeon-core' ),
				'selector' => '{{WRAPPER}} .banner-slider .slider-content .sub-title',
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'subtitle_color',
				'label'   => esc_html__( 'Subtitle Color', 'neeon-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .banner-slider .slider-content .sub-title' => 'color: {{VALUE}}',
				),
			),
			array(
				'type'    => Controls_Manager::DIMENSIONS,
				'id'      => 'subtitle_margin',
				'mode'    => 'responsive',
				'label'   => esc_html__( 'Subtitle Space', 'neeon-core' ),
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .banner-slider .slider-content .sub-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			),
			array(
				'mode' => 'section_end',
			),
            // Content style
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_content_style',
				'label'   => esc_html__( 'Content Style', 'neeon-core' ),
				'tab'     => Controls_Manager::TAB_STYLE,
			),
			array (
				'mode'    => 'group',
				'type'    => Group_Control_Typography::get_type(),
				'name'    => 'content_typo',
				'label'   => esc_html__( 'Content Typo', 'neeon-core' ),
				'selector' => '{{WRAPPER}} .banner-slider .slider-content .slider-text',
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'content_color',
				'label'   => esc_html__( 'Content Color', 'neeon-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .banner-slider .slider-content .slider-text' => 'color: {{VALUE}}',
				),
			),
			array(
				'type'    => Controls_Manager::DIMENSIONS,
				'id'      => 'content_margin',
				'mode'    => 'responsive',
				'label'   => esc_html__( 'Content Space', 'neeon-core' ),
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .banner-slider .slider-content .slider-text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			),
			array(
				'type' => Controls_Manager::CHOOSE,
				'id'      => 'text_align',
				'label'   => esc_html__( 'Alignment', 'neeon-core' ),
				'options' => array(
					'left' => array(
						'title' => __( 'Left', 'elementor' ),
						'icon' => 'eicon-text-align-left',
					),
					'center' => array(
						'title' => __( 'Center', 'elementor' ),
						'icon' => 'eicon-text-align-center',
					),
					'right' => array(
						'title' => __( 'Right', 'elementor' ),
						'icon' => 'eicon-text-align-right',
					),
				),
				'default' => '',
			),
			array(
				'type' 			=> Controls_Manager::SLIDER,
				'mode' 			=> 'responsive',
				'id'      		=> 'text_width',
				'label'   		=> esc_html__( 'Text Width', 'neeon-core' ),						
				'size_units' => array( 'px', '%' ),
				'default' => array(
				'unit' => '%',
				'size' => '',
				),
				'range' => array(
	                'px' => array(
	                    'min' => 0,
	                    'max' => 1200,
	               	),
	               	'%' => array(
	                    'min' => 0,
	                    'max' => 100,
	               	),
		       	),
				'selectors' => array(
					'{{WRAPPER}} .banner-slider .slider-content .slider-text' => 'max-width: {{SIZE}}{{UNIT}};',
				)
			),
			array(
				'mode' => 'section_end',
			),
			// Button style
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_button',
				'label'   => esc_html__( 'Button Style', 'neeon-core' ),
				'tab'     => Controls_Manager::TAB_STYLE,
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'button_display',
				'label'       => esc_html__( 'Button Display', 'neeon-core' ),
				'label_on'    => esc_html__( 'On', 'neeon-core' ),
				'label_off'   => esc_html__( 'Off', 'neeon-core' ),
				'default'     => 'yes',
				'description' => esc_html__( 'Show or Hide Content. Default: off', 'neeon-core' ),
			),
			array(
				'type'    => Controls_Manager::NUMBER,
				'id'      => 'button_size',
				'label'   => esc_html__( 'Button Size', 'neeon-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .banner-slider .btn-common' => 'font-size: {{VALUE}}px',
				),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'button_bg_color',
				'label'   => esc_html__( 'Button Bg Color', 'neeon-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .banner-slider .btn-common' => 'background-color: {{VALUE}}',
				),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'button_color',
				'label'   => esc_html__( 'Button Color', 'neeon-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .banner-slider .btn-common' => 'color: {{VALUE}}',
					'{{WRAPPER}} .banner-slider .btn-common path.rt-button-cap' => 'stroke: {{VALUE}}',
				),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'button_hover_color',
				'label'   => esc_html__( 'Button Hover Color', 'neeon-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .banner-slider .btn-common:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} .banner-slider .btn-common:hover path.rt-button-cap' => 'stroke: {{VALUE}}',
				),
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'mode'          => 'responsive',
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'button_padding',
	            'label'   => __( 'Padding', 'neeon-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .banner-slider .btn-common' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			// Shape style
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_animation',
				'label'   => esc_html__( 'Animation', 'neeon-core' ),
				'tab'     => Controls_Manager::TAB_STYLE,
			),

			array(
				'type'    => Controls_Manager::SELECT2,
				'id'          => 'animation',
				'label'       => esc_html__( 'Animation', 'neeon-core' ),
				'description' => esc_html__( 'Show or Hide animation. Default: true', 'neeon-core' ),
				'options' => array(
					'animation' => esc_html__( 'On', 'neeon-core' ),
					'animation-off' => esc_html__( 'Off', 'neeon-core' ),
				),
				'default' => 'animation',
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'shape_display',
				'label'       => esc_html__( 'Shape Display', 'neeon-core' ),
				'label_on'    => esc_html__( 'On', 'neeon-core' ),
				'label_off'   => esc_html__( 'Off', 'neeon-core' ),
				'default'     => 'yes',
				'description' => esc_html__( 'Show or Hide Shape. Default: On', 'neeon-core' ),
			),
			array(
				'mode' => 'section_end',
			),

			array(
				'mode'        => 'section_start',
				'id'          => 'sec_slider_pervice',
				'label'       => esc_html__( 'Slides PerView Options', 'consalty-core' ),
			),
			
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'desktop',
				'label'   => esc_html__( 'Desktops: > 1600px', 'consalty-core' ),
				'default' => '2',
				'options' => array(
					'1' => esc_html__( '1', 'consalty-core' ),
					'2' => esc_html__( '2', 'consalty-core' ),
					'3' => esc_html__( '3',  'consalty-core' ),
					'4' => esc_html__( '4',  'consalty-core' ),
				),
			),

			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'md_desktop',
				'label'   => esc_html__( 'Desktops: > 1200px', 'consalty-core' ),
				'default' => '3.5',
				'options' => array(
					'1' => esc_html__( '1', 'consalty-core' ),
					'1.5' => esc_html__( '1.5', 'consalty-core' ),
					'2.5' => esc_html__( '2.5', 'consalty-core' ),
					'3.5' => esc_html__( '3.5',  'consalty-core' ),
				),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'sm_desktop',
				'label'   => esc_html__( 'Desktops: > 992px', 'consalty-core' ),
				'default' => '2.5',
				'options' => array(
					'1' => esc_html__( '1', 'consalty-core' ),
					'1.5' => esc_html__( '1.5', 'consalty-core' ),
					'2.5' => esc_html__( '2.5', 'consalty-core' ),
					'3.5' => esc_html__( '3.5',  'consalty-core' ),
				),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'tablet',
				'label'   => esc_html__( 'Tablets: > 768px', 'consalty-core' ),
				'default' => '2',
				'options' => array(
					'1' => esc_html__( '1', 'consalty-core' ),
					'2' => esc_html__( '2', 'consalty-core' ),
					'3' => esc_html__( '3',  'consalty-core' ),
				),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'mobile',
				'label'   => esc_html__( 'Phones: > 576px', 'consalty-core' ),
				'default' => '1.5',
				'options' => array(
					'1' => esc_html__( '1', 'consalty-core' ),
					'1.5' => esc_html__( '1.5', 'consalty-core' ),
					'2.5' => esc_html__( '2.5', 'consalty-core' ),
					'3.5' => esc_html__( '3.5',  'consalty-core' ),
				),
			),
			array(
				'mode' => 'section_end',
			),
        );

		return $fields;
	}

	protected function render() {

		$data = $this->get_settings();
        if($data['slider_autoplay']=='yes'){
			$data['slider_autoplay']=true;
		}
		else{
			$data['slider_autoplay']=false;
		}



		$swiper_data = array(
			'slidesPerView' 	=>2,
			'centeredSlides'	=>$data['centered_slides']=='yes' ? true:false ,
			'loop'				=>$data['slider_loop']=='yes' ? true:false,
			'spaceBetween'		=>$data['slides_space'],
			'slidesPerGroup'	=>$data['slides_per_group']['size'],
			'slideToClickedSlide' =>true,
			'autoplay'				=>array(
				'delay'  => $data['slider_autoplay_delay'],
			),
			'speed'      =>$data['slider_autoplay_speed'],
			'breakpoints' =>array(
				'0'    =>array('slidesPerView' =>1),
				'576'    =>array('slidesPerView' =>$data['mobile']),
				'768'    =>array('slidesPerView' =>$data['tablet']),
				'992'    =>array('slidesPerView' =>$data['sm_desktop']),
				'1200'    =>array('slidesPerView' =>$data['md_desktop']),				
				'1600'    =>array('slidesPerView' =>$data['desktop'])				

			),
			'auto'   =>$data['slider_autoplay']
		);


		$template = 'banner-slider';
        $data['swiper_data'] = json_encode( $swiper_data );   
		return $this->rt_template( $template, $data );
	}
}